@@ -199,4 +199,6 @@ sub dump
 
 }  # End of package's lexical scope
 
-1;
+
+# Ensure correct versioning
+($Object::InsideOut::VERSION == 1.43) or die("Version mismatch\n");
