@@ -271,4 +271,6 @@ sub inherit
 
 }  # End of package's lexical scope
 
-1;
+
+# Ensure correct versioning
+($Object::InsideOut::VERSION == 1.43) or die("Version mismatch\n");
