@@ -64,4 +64,6 @@ sub generate_OVERLOAD :Private
 
 }  # End of package's lexical scope
 
-1;
+
+# Ensure correct versioning
+($Object::InsideOut::VERSION == 1.43) or die("Version mismatch\n");
